﻿package ru.k0t0vich.fluent.parsers 
{
	import ru.k0t0vich.fluent.FluentList;
	/**
	 * Парсер XML вида:
	 * 
		<?xml version="1.0" encoding="utf-8" ?>
		<script>
			<where field="z" conditon=">" value="-80"/>
			<where field="z" conditon="<" value="-50"/>
			<or/>
			<where field="level" conditon="==" value="1"/>
			<sort field="z" by="numeric" />
			<call function="doShoot" args="1,10">
		</script>
	 * @author k0t0vich
	 */
	public class FluentXMLParser
	{
		
		public static function parse(fluentList:FluentList, xml:XML):FluentList
		{
			var retList:FluentList = fluentList;
			var len:int = xml.*.length()
			for (var i:int = 0; i < len; i++) 
			{
				var child:XML= xml.*[i];
				var command:String = child.name();
				switch(command)
				{
					case FluentCommand.CALL:
						retList = retList.call(child.attribute(CallAttributes.FUNCTION), String(child.attribute(CallAttributes.ARGS)).split(","));
					break;	
					case FluentCommand.WHERE:
						var field:String = child.attribute(WhereAttributes.FIELD);
						var condition:String = child.attribute(WhereAttributes.CONDITION);
						var value:* = child.attribute(WhereAttributes.VALUE);
						retList.where(field,condition, value);						
					break;
					case FluentCommand.SORT:
					case FluentCommand.SORTON:
						var options:int = 0;
						switch(child.attribute(SortAttributes.BY))
						{
							case SortAttributes.NUMERIC:
								options = Array.NUMERIC;
							break;
							//TODO: прописать остальные типы сортировки
							default:
								options = 0;
							break;
						}
						retList = retList.sortOn(child.attribute(SortAttributes.FIELD),options);
					break;
					case FluentCommand.OR:
					case FluentCommand.JOIN:
						retList.or();
					break;
					case FluentCommand.GROUP:
						retList = retList.group();
					break;
					default:
						throw(new Error("'" + command + "' is illegal command of FluentXML"));
					break;
					
				}
			}
			return retList;
			
		}
		
	}

}